==> haskell-hls-explicit-fixity-plugin-2.0.0.0-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.0.0.0-INj5Uyuoh2Z3aDLg9RLyKX
key:                  hls-explicit-fixity-plugin-2.0.0.0-INj5Uyuoh2Z3aDLg9RLyKX
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  d22238cf0b23ea7f07082400c67acdfd
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.0.0.0-INj5Uyuoh2Z3aDLg9RLyKX
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-9yFW5HMy3QJKMvZBMWGOPz ghc-9.4.8
    ghcide-2.0.0.0-4aPLgQYWLRp5dlMy8HP7Nk
    hashable-1.4.4.0-3P57kjJkCag7O0bwYoaxX1
    hls-plugin-api-2.0.0.0-81BySD4vqkK8F619Geablm
    lsp-1.6.0.0-JssQdMMkdnV6Y1aZJgkn3p text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-explicit-fixity-plugin-2.0.0.0-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-explicit-fixity-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-fixity-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-explicit-fixity-plugin-2.0.0.0-1ZrJmCg5AVZ4yTwVcdK6Ej
key:                  hls-explicit-fixity-plugin-2.0.0.0-1ZrJmCg5AVZ4yTwVcdK6Ej
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Show fixity explicitly while hovering
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-explicit-fixity-plugin#readme>

category:             Development
abi:                  2bae38d5b7301c84817861a5a4c5bb50
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitFixity
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-explicit-fixity-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-fixity-plugin
hs-libraries:         HShls-explicit-fixity-plugin-2.0.0.0-1ZrJmCg5AVZ4yTwVcdK6Ej
depends:
    base-4.17.2.1 containers-0.6.7 deepseq-1.4.8.0
    extra-1.7.16-EuapY98rdrN25pzQYLq3T2 ghc-9.4.8
    ghcide-2.0.0.0-Ci6TVgvzKoWAIiVzj2Rzr7
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    hls-plugin-api-2.0.0.0-JrJwLgvgULIKBoKUOgpowV
    lsp-1.6.0.0-2KeiYBxXLvVGpdNjURDfN5 text-2.0.2 transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-fixity-plugin/html/hls-explicit-fixity-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-fixity-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
